==> blesta-5.10.2.zip: blesta/language/da_dk/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.!error.action_id.valid'] = 'Ugyldigt handlings-ID';
$lang['Navigation.!error.order.valid'] = 'Ordreindekset skal være en numerisk værdi';
$lang['Navigation.!error.parent_id.valid'] = 'Ugyldigt ID for overordnet navigationselement';
$lang['Navigation.getprimary.nav_home'] = 'Hjem';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Dashboard';
$lang['Navigation.getprimary.nav_clients'] = 'Kunder';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Gennemse kunder';
$lang['Navigation.getprimary.nav_billing'] = 'Fakturering';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Oversigt';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Fakturaer';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Citater';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Transaktioner';
$lang['Navigation.getprimary.nav_billing_services'] = 'Tjenester';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Rapporter';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Udskriftskø';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Batch';
$lang['Navigation.getprimary.nav_packages'] = 'Pakker';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Gennemse pakker';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Pakkegrupper';
$lang['Navigation.getprimary.nav_package_options'] = 'Konfigurerbare muligheder';
$lang['Navigation.getprimary.nav_tools'] = 'Værktøj';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Logfiler';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Konverter valuta';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Hjælpeprogrammer';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Kø til fornyelse';
$lang['Navigation.getprimary.nav_settings_company'] = 'Virksomhed';
$lang['Navigation.getprimary.nav_settings_system'] = 'System';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Dashboard';
$lang['Navigation.getprimaryclient.nav_services'] = 'Tjenester';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Betalingskonti';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Tilføj betalingskonto';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Kontaktpersoner';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Tilføj kontakt';
$lang['Navigation.getprimaryclient.nav_return'] = 'Tilbage til instrumentbrættet';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Hjem';
$lang['Navigation.getcompany.nav_general'] = 'Generelt';
$lang['Navigation.getcompany.nav_general_localization'] = 'Lokalisering';
$lang['Navigation.getcompany.nav_general_international'] = 'Internationalisering';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Kryptering';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Kontakttyper';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Markedsføring';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Smart søgning';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Menneskelig verifikation';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Udseende og fornemmelse';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Temaer';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Skabelon';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Layout';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Navigation';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Handlinger';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Tilpas';
$lang['Navigation.getcompany.nav_automation'] = 'Automatisering';
$lang['Navigation.getcompany.nav_billing'] = 'Fakturering/betaling';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Faktura- og opkrævningsmuligheder';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Tilpasning af fakturaer';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Levering af fakturaer';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Gebyrer for forsinket betaling';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Meddelelser';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Kuponer';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Accepterede betalingstyper';
$lang['Navigation.getcompany.nav_modules'] = 'Moduler';
$lang['Navigation.getcompany.nav_messengers'] = 'Budbringere';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Budbringere';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Messenger-konfiguration';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Skabeloner til beskeder';
$lang['Navigation.getcompany.nav_gateways'] = 'Betalingsgateways';
$lang['Navigation.getcompany.nav_taxes'] = 'Skatter';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Grundlæggende skatteindstillinger';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Skatteregler';
$lang['Navigation.getcompany.nav_emails'] = 'E-mails';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Mail-indstillinger';
$lang['Navigation.getcompany.nav_emails_templates'] = 'E-mail-skabeloner';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Underskrifter';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Kundemuligheder';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Generelle klientindstillinger';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Brugerdefinerede kundefelter';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Påkrævede kundefelter';
$lang['Navigation.getcompany.nav_currencies'] = 'Valutaer';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Opsætning af valuta';
$lang['Navigation.getcompany.nav_currency_active'] = 'Aktive valutaer';
$lang['Navigation.getcompany.nav_plugins'] = 'Plugins';
$lang['Navigation.getcompany.nav_groups'] = 'Kundegrupper';
$lang['Navigation.getcompany.nav_feeds'] = 'Datafeeds';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Generelt';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Indstillinger for foder';
$lang['Navigation.getsystem.nav_general'] = 'Generelt';
$lang['Navigation.getsystem.nav_general_basic'] = 'Grundlæggende opsætning';
$lang['Navigation.getsystem.nav_general_geoip'] = 'GeoIP-indstillinger';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Vedligeholdelse';
$lang['Navigation.getsystem.nav_general_license'] = 'Licensnøgle';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Betalingstyper';
$lang['Navigation.getsystem.nav_automation'] = 'Automatisering';
$lang['Navigation.getsystem.nav_companies'] = 'Virksomheder';
$lang['Navigation.getsystem.nav_backup'] = 'Sikkerhedskopiering';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Sikker FTP';
$lang['Navigation.getsystem.nav_backup_index'] = 'På forespørgsel';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_staff'] = 'Personale';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Ledelse af personale';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Medarbejdergrupper';
$lang['Navigation.getsystem.nav_api'] = 'API-adgang';
$lang['Navigation.getsystem.nav_upgrade'] = 'Opgraderingsmuligheder';
$lang['Navigation.getsystem.nav_help'] = 'Hjælp';
$lang['Navigation.getsystem.nav_help_index'] = 'Ressourcer';
$lang['Navigation.getsystem.nav_help_notes'] = 'Udgivelsesnoter';
$lang['Navigation.getsystem.nav_help_about'] = 'Om Blesta';
$lang['Navigation.getsystem.nav_marketplace'] = 'Markedsplads';
$lang['Navigation.getsearchoptions.smart'] = 'Smart søgning';
$lang['Navigation.getsearchoptions.clients'] = 'Klientsøgning';
$lang['Navigation.getsearchoptions.invoices'] = 'Fakturasøgning';
$lang['Navigation.getsearchoptions.transactions'] = 'Transaktionssøgning';
$lang['Navigation.getsearchoptions.services'] = 'Service-søgning';
$lang['Navigation.getsearchoptions.packages'] = 'Pakkesøgning';
$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Sort liste';

==> blesta-5.11.4.zip: blesta/language/da_dk/navigation.php <==
<?php
/**
 * Navigation
 *
 * @package blesta
 * @subpackage blesta.language.da_dk
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['Navigation.!error.action_id.valid'] = 'Ugyldigt handlings-ID';
$lang['Navigation.!error.order.valid'] = 'Ordreindekset skal være en numerisk værdi';
$lang['Navigation.!error.parent_id.valid'] = 'Ugyldigt ID for overordnet navigationselement';
$lang['Navigation.getprimary.nav_home'] = 'Hjem';
$lang['Navigation.getprimary.nav_home_dashboard'] = 'Dashboard';
$lang['Navigation.getprimary.nav_clients'] = 'Kunder';
$lang['Navigation.getprimary.nav_clients_browse'] = 'Gennemse kunder';
$lang['Navigation.getprimary.nav_billing'] = 'Fakturering';
$lang['Navigation.getprimary.nav_billing_overview'] = 'Oversigt';
$lang['Navigation.getprimary.nav_billing_invoices'] = 'Fakturaer';
$lang['Navigation.getprimary.nav_billing_quotations'] = 'Citater';
$lang['Navigation.getprimary.nav_billing_transactions'] = 'Transaktioner';
$lang['Navigation.getprimary.nav_billing_services'] = 'Tjenester';
$lang['Navigation.getprimary.nav_billing_reports'] = 'Rapporter';
$lang['Navigation.getprimary.nav_billing_printqueue'] = 'Udskriftskø';
$lang['Navigation.getprimary.nav_billing_batch'] = 'Batch';
$lang['Navigation.getprimary.nav_packages'] = 'Pakker';
$lang['Navigation.getprimary.nav_packages_browse'] = 'Gennemse pakker';
$lang['Navigation.getprimary.nav_packages_groups'] = 'Pakkegrupper';
$lang['Navigation.getprimary.nav_package_options'] = 'Konfigurerbare muligheder';
$lang['Navigation.getprimary.nav_tools'] = 'Værktøj';
$lang['Navigation.getprimary.nav_tools_logs'] = 'Logfiler';
$lang['Navigation.getprimary.nav_tools_currency'] = 'Konverter valuta';
$lang['Navigation.getprimary.nav_tools_utilities'] = 'Hjælpeprogrammer';
$lang['Navigation.getprimary.nav_tools_renewals'] = 'Kø til fornyelse';
$lang['Navigation.getprimary.nav_settings_company'] = 'Virksomhed';
$lang['Navigation.getprimary.nav_settings_system'] = 'System';
$lang['Navigation.getprimaryclient.nav_dashboard'] = 'Dashboard';
$lang['Navigation.getprimaryclient.nav_services'] = 'Tjenester';
$lang['Navigation.getprimaryclient.nav_paymentaccounts'] = 'Betalingskonti';
$lang['Navigation.getprimaryclient.nav_paymentaccounts_add'] = 'Tilføj betalingskonto';
$lang['Navigation.getprimaryclient.nav_contacts'] = 'Kontaktpersoner';
$lang['Navigation.getprimaryclient.nav_contacts_add'] = 'Tilføj kontakt';
$lang['Navigation.getprimaryclient.nav_return'] = 'Tilbage til instrumentbrættet';
$lang['Navigation.getprimarypublic.nav_dashboard'] = 'Hjem';
$lang['Navigation.getcompany.nav_general'] = 'Generelt';
$lang['Navigation.getcompany.nav_general_localization'] = 'Lokalisering';
$lang['Navigation.getcompany.nav_general_international'] = 'Internationalisering';
$lang['Navigation.getcompany.nav_general_encryption'] = 'Kryptering';
$lang['Navigation.getcompany.nav_general_contacttypes'] = 'Kontakttyper';
$lang['Navigation.getcompany.nav_general_marketing'] = 'Markedsføring';
$lang['Navigation.getcompany.nav_general_smart_search'] = 'Smart søgning';
$lang['Navigation.getcompany.nav_general_humanverification'] = 'Menneskelig verifikation';
$lang['Navigation.getcompany.nav_lookandfeel'] = 'Udseende og fornemmelse';
$lang['Navigation.getcompany.nav_lookandfeel_themes'] = 'Temaer';
$lang['Navigation.getcompany.nav_lookandfeel_template'] = 'Skabelon';
$lang['Navigation.getcompany.nav_lookandfeel_layout'] = 'Layout';
$lang['Navigation.getcompany.nav_lookandfeel_navigation'] = 'Navigation';
$lang['Navigation.getcompany.nav_lookandfeel_actions'] = 'Handlinger';
$lang['Navigation.getcompany.nav_lookandfeel_customize'] = 'Tilpas';
$lang['Navigation.getcompany.nav_automation'] = 'Automatisering';
$lang['Navigation.getcompany.nav_billing'] = 'Fakturering/betaling';
$lang['Navigation.getcompany.nav_billing_invoices'] = 'Faktura- og opkrævningsmuligheder';
$lang['Navigation.getcompany.nav_billing_custominvoice'] = 'Tilpasning af fakturaer';
$lang['Navigation.getcompany.nav_billing_deliverymethods'] = 'Levering af fakturaer';
$lang['Navigation.getcompany.nav_billing_latefees'] = 'Gebyrer for forsinket betaling';
$lang['Navigation.getcompany.nav_billing_notices'] = 'Meddelelser';
$lang['Navigation.getcompany.nav_billing_coupons'] = 'Kuponer';
$lang['Navigation.getcompany.nav_billing_acceptedtypes'] = 'Accepterede betalingstyper';
$lang['Navigation.getcompany.nav_modules'] = 'Moduler';
$lang['Navigation.getcompany.nav_messengers'] = 'Budbringere';
$lang['Navigation.getcompany.nav_messengers_messengers'] = 'Budbringere';
$lang['Navigation.getcompany.nav_messengers_configuration'] = 'Messenger-konfiguration';
$lang['Navigation.getcompany.nav_messengers_templates'] = 'Skabeloner til beskeder';
$lang['Navigation.getcompany.nav_gateways'] = 'Betalingsgateways';
$lang['Navigation.getcompany.nav_taxes'] = 'Skatter';
$lang['Navigation.getcompany.nav_taxes_basictax'] = 'Grundlæggende skatteindstillinger';
$lang['Navigation.getcompany.nav_taxes_taxrules'] = 'Skatteregler';
$lang['Navigation.getcompany.nav_emails'] = 'E-mails';
$lang['Navigation.getcompany.nav_emails_mail'] = 'Mail-indstillinger';
$lang['Navigation.getcompany.nav_emails_templates'] = 'E-mail-skabeloner';
$lang['Navigation.getcompany.nav_emails_signatures'] = 'Underskrifter';
$lang['Navigation.getcompany.nav_clientoptions'] = 'Kundemuligheder';
$lang['Navigation.getcompany.nav_clientoptions_general'] = 'Generelle klientindstillinger';
$lang['Navigation.getcompany.nav_clientoptions_customfields'] = 'Brugerdefinerede kundefelter';
$lang['Navigation.getcompany.nav_clientoptions_requiredfields'] = 'Påkrævede kundefelter';
$lang['Navigation.getcompany.nav_currencies'] = 'Valutaer';
$lang['Navigation.getcompany.nav_currency_currencysetup'] = 'Opsætning af valuta';
$lang['Navigation.getcompany.nav_currency_active'] = 'Aktive valutaer';
$lang['Navigation.getcompany.nav_plugins'] = 'Plugins';
$lang['Navigation.getcompany.nav_groups'] = 'Kundegrupper';
$lang['Navigation.getcompany.nav_feeds'] = 'Datafeeds';
$lang['Navigation.getcompany.nav_feeds_general'] = 'Generelt';
$lang['Navigation.getcompany.nav_feeds_settings'] = 'Indstillinger for foder';
$lang['Navigation.getsystem.nav_general'] = 'Generelt';
$lang['Navigation.getsystem.nav_general_basic'] = 'Grundlæggende opsætning';
$lang['Navigation.getsystem.nav_general_geoip'] = 'GeoIP-indstillinger';
$lang['Navigation.getsystem.nav_general_maintenance'] = 'Vedligeholdelse';
$lang['Navigation.getsystem.nav_general_license'] = 'Licensnøgle';
$lang['Navigation.getsystem.nav_general_paymenttypes'] = 'Betalingstyper';
$lang['Navigation.getsystem.nav_automation'] = 'Automatisering';
$lang['Navigation.getsystem.nav_companies'] = 'Virksomheder';
$lang['Navigation.getsystem.nav_backup'] = 'Sikkerhedskopiering';
$lang['Navigation.getsystem.nav_backup_ftp'] = 'Sikker FTP';
$lang['Navigation.getsystem.nav_backup_index'] = 'På forespørgsel';
$lang['Navigation.getsystem.nav_backup_amazon'] = 'Amazon S3';
$lang['Navigation.getsystem.nav_staff'] = 'Personale';
$lang['Navigation.getsystem.nav_staff_manage'] = 'Ledelse af personale';
$lang['Navigation.getsystem.nav_staff_groups'] = 'Medarbejdergrupper';
$lang['Navigation.getsystem.nav_api'] = 'API-adgang';
$lang['Navigation.getsystem.nav_upgrade'] = 'Opgraderingsmuligheder';
$lang['Navigation.getsystem.nav_help'] = 'Hjælp';
$lang['Navigation.getsystem.nav_help_index'] = 'Ressourcer';
$lang['Navigation.getsystem.nav_help_notes'] = 'Udgivelsesnoter';
$lang['Navigation.getsystem.nav_help_about'] = 'Om Blesta';
$lang['Navigation.getsystem.nav_marketplace'] = 'Markedsplads';
$lang['Navigation.getsearchoptions.smart'] = 'Smart søgning';
$lang['Navigation.getsearchoptions.clients'] = 'Klientsøgning';
$lang['Navigation.getsearchoptions.invoices'] = 'Fakturasøgning';
$lang['Navigation.getsearchoptions.transactions'] = 'Transaktionssøgning';
$lang['Navigation.getsearchoptions.services'] = 'Service-søgning';
$lang['Navigation.getsearchoptions.packages'] = 'Pakkesøgning';
$lang['Navigation.getprimary.nav_tools_blacklist'] = 'Sort liste';
$lang['Navigation.getcompany.nav_html_templates'] = 'HTML-skabeloner';
$lang['Navigation.getprimary.nav_tools_provisioning'] = 'Service-kø';
